"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const eventemitter3_1 = require("eventemitter3");
const LOGEVENT = "log";
class LogsSubscriber {
    constructor(_rpc, _waitReq = {}) {
        this._rpc = _rpc;
        this._waitReq = _waitReq;
        this._emitter = new eventemitter3_1.EventEmitter();
    }
    /**
     * async loop to long-poll for new logs
     */
    async start() {
        let curblock = this._waitReq.from;
        while (true) {
            const result = await this._rpc.waitforlogs(Object.assign({}, this._waitReq, { from: curblock }));
            // advance log cursor
            curblock = result.nextblock;
            if (result.count < 1) {
                continue;
            }
            for (const log of result.entries) {
                this._emitter.emit(LOGEVENT, log);
            }
        }
    }
    on(fn) {
        this._emitter.on(LOGEVENT, fn);
    }
    once(fn) {
        this._emitter.once(LOGEVENT, fn);
    }
    off(fn) {
        this._emitter.off(LOGEVENT, fn);
    }
}
exports.LogsSubscriber = LogsSubscriber;
